aboutsummaryrefslogtreecommitdiff
path: root/engines/titanic/support/avi_surface.cpp
diff options
context:
space:
mode:
authorPaul Gilbert2016-09-28 20:24:27 -0400
committerPaul Gilbert2016-09-28 20:24:27 -0400
commitaba58e6042a1247f36379e69b3338eae1d58c999 (patch)
tree12e0207fb8c605c8f5bda808b4b70b10543cad9c /engines/titanic/support/avi_surface.cpp
parent0da273fc8c843a6248e11f006d51a4817e3d8e37 (diff)
downloadscummvm-rg350-aba58e6042a1247f36379e69b3338eae1d58c999.tar.gz
scummvm-rg350-aba58e6042a1247f36379e69b3338eae1d58c999.tar.bz2
scummvm-rg350-aba58e6042a1247f36379e69b3338eae1d58c999.zip
TITANIC: Clarify movie secondary video tracks as a transparency mask
Diffstat (limited to 'engines/titanic/support/avi_surface.cpp')
-rw-r--r--engines/titanic/support/avi_surface.cpp9
1 files changed, 5 insertions, 4 deletions
diff --git a/engines/titanic/support/avi_surface.cpp b/engines/titanic/support/avi_surface.cpp
index d4ebd5cef1..2cc32971ae 100644
--- a/engines/titanic/support/avi_surface.cpp
+++ b/engines/titanic/support/avi_surface.cpp
@@ -39,15 +39,16 @@ Video::AVIDecoder::AVIVideoTrack &AVIDecoder::getVideoTrack() {
}
/**
* Track filter for AVIDecoder that filters out any secondary video track
*/
static bool primaryTrackSelect(bool isVideo, int trackCounter) {
return !isVideo || trackCounter == 0;
}
/**
* Track filter for AVIDecoder that only accepts the secondary video track
* for a video, if present
*/
static bool secondaryTrackSelect(bool isVideo, int trackCounter) {
return isVideo && trackCounter > 0;
@@ -348,7 +349,7 @@ Graphics::ManagedSurface *AVISurface::getSecondarySurface() {
return _streamCount <= 1 ? nullptr : _movieFrameSurface[1];
}
-Graphics::ManagedSurface *AVISurface::duplicateSecondaryFrame() const {
+Graphics::ManagedSurface *AVISurface::duplicateTransparency() const {
if (_streamCount <= 1) {
return nullptr;
} else {
@@ -39,15 +39,16 @@ Video::AVIDecoder::AVIVideoTrack &AVIDecoder::getVideoTrack() {
}
/**
- * Track filter for AVIDecoder that filters out any secondary video track
+ * Track filter for AVIDecoder that filters out any secondary
+ * video track some videos have to hold transparency masks
*/
static bool primaryTrackSelect(bool isVideo, int trackCounter) {
@@ -39,15 +39,16 @@ Video::AVIDecoder::AVIVideoTrack &AVIDecoder::getVideoTrack() {
}
/**
- * Track filter for AVIDecoder that only accepts the secondary video track
- * for a video, if present
+ * Track filter for AVIDecoder that only accepts the secondary
+ * transparency msak video track for a video, if present
*/
static bool secondaryTrackSelect(bool isVideo, int trackCounter) {